EXPORTS
	??0CTestFactoryBase@Dummy@@IAE@VTUid@@AAVCTestFactoryContainer@1@@Z @ 1 NONAME ; Dummy::CTestFactoryBase::CTestFactoryBase(class TUid, class Dummy::CTestFactoryContainer &)
	??0CTestNodeBase@Dummy@@IAE@AAVCFactoryBase@Factories@@ABUTNodeActivityMap@MeshMachine@@@Z @ 2 NONAME ; Dummy::CTestNodeBase::CTestNodeBase(class Factories::CFactoryBase &, struct MeshMachine::TNodeActivityMap const &)
	??1CTestFactoryBase@Dummy@@UAE@XZ @ 3 NONAME ; Dummy::CTestFactoryBase::~CTestFactoryBase(void)
	??1CTestNodeBase@Dummy@@UAE@XZ @ 4 NONAME ; Dummy::CTestNodeBase::~CTestNodeBase(void)
	?CreateL@CTestFactoryBase@Dummy@@QAEAAVCTestNodeBase@2@XZ @ 5 NONAME ; class Dummy::CTestNodeBase & Dummy::CTestFactoryBase::CreateL(void)
	?Find@CTestFactoryBase@Dummy@@QAEPAVCTestNodeBase@2@AAVMFactoryQuery@Factories@@@Z @ 6 NONAME ; class Dummy::CTestNodeBase * Dummy::CTestFactoryBase::Find(class Factories::MFactoryQuery &)
	?FindOrCreateL@CTestFactoryBase@Dummy@@QAEAAVCTestNodeBase@2@AAVMFactoryQuery@Factories@@@Z @ 7 NONAME ; class Dummy::CTestNodeBase & Dummy::CTestFactoryBase::FindOrCreateL(class Factories::MFactoryQuery &)
	?InstallL@CTestFactoryContainer@Dummy@@SAXXZ @ 8 NONAME ; void Dummy::CTestFactoryContainer::InstallL(void)
	?ObjectBroker@TRuntimeCtxAddressBook@Dummy@@SAABVTNodeId@Messages@@XZ @ 9 NONAME ; class Messages::TNodeId const & Dummy::TRuntimeCtxAddressBook::ObjectBroker(void)
	?Received@CTestNodeBase@Dummy@@IAEXAAVTNodeContextBase@MeshMachine@@@Z @ 10 NONAME ; void Dummy::CTestNodeBase::Received(class MeshMachine::TNodeContextBase &)
	?ReceivedL@CTestNodeBase@Dummy@@MAEXABVTRuntimeCtxId@Messages@@ABVTNodeId@4@AAVTSignatureBase@4@@Z @ 11 NONAME ; void Dummy::CTestNodeBase::ReceivedL(class Messages::TRuntimeCtxId const &, class Messages::TNodeId const &, class Messages::TSignatureBase &)
	?Self@dummyActivities@DummyActivities@@SAABUTNodeActivityMap@MeshMachine@@XZ @ 12 NONAME ; struct MeshMachine::TNodeActivityMap const & DummyActivities::dummyActivities::Self(void)
	?UnInstall@CTestFactoryContainer@Dummy@@SAXXZ @ 13 NONAME ; void Dummy::CTestFactoryContainer::UnInstall(void)


